@@ -28,6 +28,7 @@ class FolderStatusDelegate : public QStyledItemDelegate
 public:
     FolderStatusDelegate();
 
+    // TODO: don't use the role but columns...
     enum datarole { FolderAliasRole = Qt::UserRole + 100,
         HeaderRole,
         FolderPathRole, // for a SubFolder it's the complete path
@@ -47,7 +48,6 @@ public:
 
         AddButton, // 1 = enabled; 2 = disabled
         FolderSyncText,
-        DataRoleCount,
 
         IsReady // boolean
     };
